package main

import (
	"context"
	"os"
	"os/signal"

	"github.com/sirupsen/logrus"

	"git.janky.solutions/finn/lockserver/config"
	"git.janky.solutions/finn/lockserver/db"
	"git.janky.solutions/finn/lockserver/httpserver"
	"git.janky.solutions/finn/lockserver/zwavejs"
)

func main() {
	run()
}

func run() {
	logrus.SetLevel(logrus.DebugLevel)

	if err := config.Load(); err != nil {
		logrus.WithError(err).Fatal("error loading config")
	}

	ctx, cancel := signal.NotifyContext(context.Background(), os.Interrupt)
	defer cancel()

	if err := db.Migrate(); err != nil {
		logrus.WithError(err).Fatal("error migrating db")
	}

	zwaveClient, err := zwavejs.New(config.C.ZWaveJSServer)
	if err != nil {
		logrus.WithError(err).Fatal("error initializing ZWaveJS connection")
	}

	go zwaveClient.DialAndListen(ctx)
	go httpserver.ListenAndServe(zwaveClient)

	<-ctx.Done()

	if err := httpserver.Shutdown(context.Background()); err != nil {
		logrus.WithError(err).Error("error shutting down http server")
	}

	if err := zwaveClient.Shutdown(); err != nil {
		logrus.WithError(err).Error("error shutting down ZWaveJS client")
	}
}
